@@ -19,11 +19,27 @@ if (marginal=="studentR"){
     y<-dt(x,df=g)
     val<-prod(y)  
 }
-if (marginal=="polyno"){
+if (marginal=="polyno.old"){
     vakio<-2*(1-1/(g+1))
     y<-vakio*abs(1-x)^g
     val<-prod(y)
 }
+if (marginal=="polyno"){ 
+    vakio<-1/(2*(1-1/(g+1)))
+    y<-vakio*abs(1-abs(x)^g)
+    val<-prod(y)
+}
+if (marginal=="double"){
+    vakio<-1/2
+    y<-exp(-abs(x))
+    val<-prod(y)
+}
+if (marginal=="gauss"){
+    vakio<-(2*pi)^(-1/2)
+    y<-exp(-x^2/2)
+    val<-prod(y)
+}
+
   
 return(val)
 }
