@@ -3,7 +3,7 @@ sig=rep(1,length(N)), support=NULL, theta=NULL,
 g=1, M=NULL, p=NULL, mul=3, t=NULL, 
 marginal="normal", r=0,
 mu=NULL, xi=NULL, Omega=NULL, alpha=NULL, df=NULL, 
-a=0.5, b=0.5, distr=FALSE, std=1) # contrast="loglik")   
+a=0.5, b=0.5, distr=FALSE, std=1, lowest=0) # contrast="loglik")   
 {
 # t<-rep(1,length(N))
 
@@ -13,14 +13,48 @@ if (d>1){
 
   if (marginal=="unif") support<-c(0,sig[1],0,sig[2])
 
-  d<-length(N)
   recnum<-prod(N)
   value<-matrix(0,recnum,1)
   index<-matrix(0,recnum,d)
 
   # new ############################################
 
-  if (func=="student"){ 
+  if (func=="mixt"){ 
+
+     support<-matrix(0,2*d,1)
+     for (i in 1:d){
+           support[2*i-1]<-min(M[,i]-mul*sig[,i])
+           support[2*i]<-max(M[,i]+mul*sig[,i])
+     }
+     lowsuppo<-matrix(0,d,1)
+     for (i in 1:d) lowsuppo[i]<-support[2*i-1]
+     step<-matrix(0,d,1)
+     for (i in 1:d) step[i]<-(support[2*i]-support[2*i-1])/N[i]
+     mixnum<-length(p)
+
+     numpositive<-0
+     for (i in 1:recnum){
+        inde<-digit(i-1,N)+1
+        point<-lowsuppo+step*inde-step/2
+        valli<-0
+        for (mi in 1:mixnum){
+            evapoint<-(point-M[mi,])/sig[mi,]
+            valli<-valli+p[mi]*evanor(evapoint)/prod(sig[mi,])
+        }
+        if (valli>lowest){
+           numpositive<-numpositive+1
+           value[numpositive]<-valli
+           index[numpositive,]<-inde
+        }
+     }
+     value<-value[1:numpositive]
+     index<-index[1:numpositive,]
+     down<-index-1
+     high<-index
+  }
+
+
+  else if (func=="student"){ 
      lowsuppo<-matrix(0,d,1)
      for (i in 1:d) lowsuppo[i]<-support[2*i-1]
      step<-matrix(0,d,1)
@@ -43,7 +77,7 @@ if (d>1){
      high<-index
   }
 
-  if (func=="gauss"){ 
+  else if (func=="gauss"){ 
      lowsuppo<-matrix(0,d,1)
      for (i in 1:d) lowsuppo[i]<-support[2*i-1]
      step<-matrix(0,d,1)
@@ -98,20 +132,13 @@ if (d>1){
      high<-index
   }
 
+
 else{
 
 # old #########################################################
 
 if (is.null(support)){
 
-   if (func=="mixt"){
-     support<-matrix(0,2*d,1)
-        for (i in 1:d){
-           support[2*i-1]<-min(M[,i]-mul*sig[,i])
-           support[2*i]<-max(M[,i]+mul*sig[,i])
-        }
-   }
-
    if (func=="epan"){
       if (is.null(sig)) sig<-c(1,1)
       support<-matrix(0,2*d,1)
@@ -120,6 +147,7 @@ if (is.null(support)){
           support[2*i]<-sig[i]
       }
    }
+
 }
 
 if ((marginal=="unif")) support<-c(0,sig[1],0,sig[2])
@@ -145,7 +173,7 @@ for (i in 1:recnum){
 
     if (func=="prod") valli<-eva.prod(point,marginal,g)
     if (func=="skewgauss") valli<-eva.skewgauss(point,mu,sig,alpha)
-    if (func=="dmsn") valli<-dmsn(point,xi,Omega,alpha)
+    #if (func=="dmsn") valli<-dmsn(point,xi,Omega,alpha)
     if (func=="gumbel") valli<-eva.copula(point,
         type="gumbel",marginal=marginal,sig=sig,r=r,t=t,g=g)
     if (func=="frank") valli<-eva.copula(point,
@@ -156,16 +184,8 @@ for (i in 1:recnum){
         type="clayton",marginal=marginal,sig=sig,r=r,t=t,g=g)
     if (func=="cop6") valli<-eva.cop6(point,t,marginal,sig)
     if (func=="epan") valli<-epan(point)
-    if (func=="normal") valli<-eva.gauss(point,t=t,marginal=marginal,sig=sig,r=r)
-    if (func=="mixt"){
-        valli<-0
-        mixnum<-length(p)
-        for (mi in 1:mixnum){
-            evapoint<-(point-M[mi,])/sig[mi,]
-            valli<-valli+p[mi]*evanor(evapoint)/prod(sig[mi,])
-        }
-    }
-   if (func=="hat") valli<-eva.hat(point,a=a,b=b)
+    if (func=="normal") valli<-eva.gauss(point,t=t,marginal=marginal,sig=sig,r=r)   
+    if (func=="hat") valli<-eva.hat(point,a=a,b=b)
 
     if (valli>0){
        numpositive<-numpositive+1
