@@ -2,7 +2,7 @@ plot.kernscale<-function(scale,maxy0=0)
 {
    hnum<-length(scale$hseq)
    for (i in 1:hnum){
-     pk<-lk$pcfseq[[i]]
+     pk<-scale$pcfseq[[i]]
      dp<-draw.pcf(pk)
      if (i==1){ 
            minx<-min(dp$x) 
@@ -20,7 +20,7 @@ plot.kernscale<-function(scale,maxy0=0)
    maxy<-max(maxy,maxy0)
    plot(x="",y="",xlim=c(minx,maxx),ylim=c(miny,maxy),xlab="",ylab="")
    for (i in 1:hnum){
-     pk<-lk$pcfseq[[i]]
+     pk<-scale$pcfseq[[i]]
      dp<-draw.pcf(pk)
      matpoints(dp$x,dp$y,type="l")
    }
