@@ -1,10 +1,11 @@
-support<-function(dendat,epsi){
+support<-function(dendat,epsi=0)
+{
 #estimoi kantajan tih datan perusteella
 #dendat on n*xlkm matriisi
 #epsi on tekn parametri
 #kantajaksi estimoidaan [min-epsi,max+epsi]
 #palauttaa xlkm*2-matriisin
-#
+
 xlkm<-length(dendat[1,])    #dendat matr sarakk lkm on muuttujien lkm
 vast<-matrix(0,xlkm,2)  
 i<-1
@@ -16,3 +17,4 @@ while (i<=xlkm){
 return(vast)
 }
 
+
